@@ -5,6 +5,6 @@ MEMORY_SIZE_DEFAULT = 8
 GPU_COUNT_DEFAULT = 0
 GPU_TYPE_DEFAULT = 'NVIDIA_TESLA_P4'
 REGION_DEFAULT = 'us-west2'
-IMAGE_TAG_DEFAULT = 'main'
+IMAGE_TAG_DEFAULT = ''
 IMAGE_URL_DEFAULT = ''
-OPTIONS_DEFAULT = '{}'
+OPTIONS_DEFAULT = {}
